@@ -121,11 +121,14 @@ def check_access_rights(service: str,
     return check_rights
 
 
-def get_user_email(token: AnyStr=None) -> str:
+def get_user_email(token: AnyStr=None, auth_enabled=True) -> str:
     """
     retrieves user id from connexion header.
     may raise ValueError if Authorization token is invalid or if token did not have uid specified
     """
+    if not auth_enabled:
+        # To prevent errors in dev env
+        return None
     if token is None:
         token = request.headers.get('Authorization', '').split(' ').pop()
         if not token:
